class ExpiredPremium(Exception):
    pass

class LimitedMessage(Exception):
    pass

class SecuredMessage(Exception):
    pass

class Accessblocked(Exception):
    pass

class CancelledTask(Exception):
    pass

class InvalidReply(Exception):
    pass

class Positivemode(Exception):
    pass

class Negativemode(Exception):
    pass

class InvalidKey(Exception):
    pass

class Cancelled(Exception):
    pass



appname = 'oxgram'
version = '0.0.8'

caption = 'ㅤ'
pythons = '~=3.10'
clinton = 'Clinton Abraham'
profile = 'https://github.com/Clinton-Abraham'

install = ['tgcryptos']
mention = ['bot', 'bots', 'telegram']

DATA01 = 'clintonabrahamc@gmail.com'
DATA02 = ['Natural Language :: English',
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'Programming Language :: Python :: 3.10',
          'Programming Language :: Python :: 3.11',
          'Programming Language :: Python :: 3.12',
          'Programming Language :: Python :: 3.13',
          'Programming Language :: Python :: 3.14',
          'Topic :: Software Development :: Libraries',
          'Topic :: Software Development :: Localization',
          'Topic :: Software Development :: User Interfaces',
          'Topic :: Software Development :: Version Control']



class SMessage:

    def __init__(self, **kwargs):
        self.errors = kwargs.get("errors", None)
        self.result = kwargs.get("result", None)
        self.numfiles = kwargs.get('numfiles', 0)
        self.filesize = kwargs.get('filesize', 0)
        self.allfiles = kwargs.get('allfiles', [])
        self.filename = kwargs.get("filename", None)
        self.taskcode = kwargs.get("taskcode", 5000)
        self.location = kwargs.get('location', None)
        self.filetype = kwargs.get("filetype", None)
        self.extension = kwargs.get("extension", None)
        self.thumbnail = kwargs.get("thumbnail", None)



from ..exceptions import InvalidKey
from ..exceptions import Negativemode
from ..exceptions import InvalidReply
from ..exceptions import Accessblocked
from ..exceptions import CancelledTask
from ..exceptions import LimitedMessage
from ..exceptions import ExpiredPremium
#=====================================================================

class BMessage:

    async def get01(message, errors=None):
        if message:
            raise CancelledTask(errors)

    async def get02(message, errors=None):
        if not message:
            raise CancelledTask(errors)

    async def get03(blocked, errors=None):
        if blocked:
            raise Accessblocked(errors)

    async def get04(blocked, errors=None):
        if not blocked:
            raise Accessblocked(errors)

    async def get05(taskuid, storage, errors=None):
        if taskuid in storage:
            raise CancelledTask(errors)

    async def get06(taskuid, storage, errors=None):
        if taskuid not in storage:
            raise CancelledTask(errors)

    async def get07(taskuid, storage, errors=None):
        if taskuid in storage:
            raise CancelledTask(errors)
        storage.append(taskuid)

    async def get08(taskuid, storage, errors=None):
        if taskuid not in storage:
            raise CancelledTask(errors)
        storage.append(taskuid)

    async def get09(message, incoming, errors=None):
        if message.startswith(incoming):
            raise CancelledTask(errors)

    async def get10(message, incoming, errors=None):
        if message.endswith(incoming):
            raise CancelledTask(errors)

    async def get11(message, incoming, errors=None):
        if not message.startswith(incoming):
            raise CancelledTask(errors)

    async def get12(message, incoming, errors=None):
        if not message.endswith(incoming):
            raise CancelledTask(errors)
    
    async def get21(message, status=False, errors=None):
        if message is status:
            raise InvalidReply(errors)

    async def get22(message, status=False, errors=None):
        if message == status:
            raise InvalidReply(errors)

    async def get23(message, status=False, errors=None):
        if message is status:
            raise Negativemode(errors)

    async def get24(message, status=False, errors=None):
        if message == status:
            raise Negativemode(errors)
    
    async def get31(minimum, maximum=1024, errors=None):
        if minimum < maximum:
            raise ExpiredPremium(errors)

    async def get32(minimum, maximum=1024, errors=None):
        if len(minimum) > maximum:
            raise LimitedMessage(errors)

    async def get41(incoming, message, errors=None):
        if incoming or message:
            raise CancelledTask(errors)

    async def get42(incoming, message, errors=None):
        if incoming and message:
            raise CancelledTask(errors)

    async def get43(incoming, message, errors=None):
        if not incoming or not message:
            raise CancelledTask(errors)
    
    async def get44(incoming, message, errors=None):
        if not incoming and not message:
            raise CancelledTask(errors)

    async def get51(message, skiplist, errors=None):
        for command in message.split():
            if command.lower() in skiplist:
                raise InvalidKey(command)

    async def get52(message, skiplist, errors=None):
        for command in message.split():
            if command.upper() in skiplist:
                raise InvalidKey(command)

#=====================================================================



from pyrogram.enums import MessageEntityType
#==============================================================================================

class Flinks:

    async def get01(update, incoming):
        amoend = filter(lambda o: o.type == MessageEntityType.URL, update.entities)
        amoond = list(amoend)
        neomos = amoond[0].offset
        sosmso = amoond[0].length
        linked = incoming[ neomos : neomos + sosmso ]
        return linked

#==============================================================================================



from .collections import SMessage
from pyrogram.enums import ChatMemberStatus
from pyrogram.errors import UserNotParticipant
#====================================================================

class Channel:

    async def main(users):
        if (users.status == ChatMemberStatus.BANNED):
            return 200
        else:
            return 100

#====================================================================

    async def get01(bot, update, channel=None):
        if not channel:
            return SMessage(taskcode=100)
        try:
            userid = update.from_user.id
            usered = await bot.get_chat_member(channel, userid)
            userod = await Channel.main(usered)
            return SMessage(taskcode=userod)
        except UserNotParticipant:
            return SMessage(taskcode=300)
        except Exception as errors:
            return SMessage(taskcode=400, errors=errors)

#====================================================================



from setuptools import find_packages
from setuptools import setup
from Oxgram import appname
from Oxgram import version
from Oxgram import install
from Oxgram import caption
from Oxgram import pythons
from Oxgram import clinton
from Oxgram import profile
from Oxgram import mention
from Oxgram import DATA01
from Oxgram import DATA02

with open("README.md", "r") as o:
    description = o.read()
    
setup(
    url=profile,
    name=appname,
    author=clinton,
    version=version,
    keywords=mention,
    classifiers=DATA02,
    author_email=DATA01,
    description=caption,
    python_requires=pythons,
    packages=find_packages(),
    install_requires=install,
    long_description=description,
    long_description_content_type="text/markdown")



from .exceptions import ExpiredPremium
from .exceptions import LimitedMessage
from .exceptions import SecuredMessage
from .exceptions import Accessblocked
from .exceptions import CancelledTask
from .exceptions import InvalidReply
from .exceptions import Positivemode
from .exceptions import Negativemode
from .exceptions import InvalidKey
from .exceptions import Cancelled
